#
# This file is part of Dancer2-Plugin-Feed
#
# This software is copyright (c) 2016 by Natal Ngétal.
#
# This is free software; you can redistribute it and/or modify it under
# the same terms as the Perl 5 programming language system itself.
#

# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.043.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "ExtUtils::MakeMaker" => 0,
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "Easy to generate feed rss or atom for Dancer2 applications.",
  "dist_author" => [
    "Natal Ng\x{e9}tal"
  ],
  "dist_name" => "Dancer2-Plugin-Feed",
  "dist_version" => "1.160550",
  "license" => "perl",
  "module_name" => "Dancer2::Plugin::Feed",
  "recursive_test_files" => 1,
  "requires" => {
    "Dancer2::Plugin" => 0,
    "XML::Feed" => 0
  },
  "test_requires" => {
    "Dancer2" => 0,
    "HTTP::Request::Common" => 0,
    "Plack::Test" => 0,
    "Test::More" => 0,
    "lib" => 0,
    "strict" => 0,
    "warnings" => 0
  }
);


my %fallback_build_requires = (
  "Dancer2" => 0,
  "HTTP::Request::Common" => 0,
  "Module::Build" => "0.28",
  "Plack::Test" => 0,
  "Test::More" => 0,
  "lib" => 0,
  "strict" => 0,
  "warnings" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
